==> metrics-broker-0.0.3.tgz: package/instruments/counter.js <==
/**
 * This file implements basic counter functionality for JavaScript programs
 * that use the metrics broker.
 *
 * Example code:
 *
 * require('metrics-broker/instruments').Counter;
 *
 * var name = 'actions';
 * var dimensions = { cust: 'custA', ... };
 * Counter.inc(name, dimensions, [val], [callback]);
 *
 * In most cases, val and callback may be omitted.
 *
 * See the README for more information on names and dimensions.
 */

var types = require('../broker').types;
var client = require('../broker').client;

/** 
 * Increments the specified counter in the broker.
 *
 * @param {String} name The name of the counter.
 * @param {Object} dimensions The dimensions of the counter.  May be null, if
 *  no dimensions are desired.
 * @param {Number} val The amount by which to increment the counter (default: 1)
 * @param {Function(String)} callback A callback to be invoked after the
 *  message has been sent.  Most code can safely omit this.
 */
exports.inc = function inc(name, dimensions, val, callback) {
  if (! name) {
    throw new Error('No name specified');
  }
  if (dimensions && (typeof dimensions !== 'object')) {
    throw new Error('Dimensions must be an object');
  }
  if (val === null || val === undefined) {
    val = 1;
  }
  client.send(types.COUNTER, 'INC', name, dimensions, val, callback);
};


/** 
 * Decrements the specified counter in the broker.
 *
 * @param {String} name The name of the counter.
 * @param {Object} dimensions The dimensions of the counter.  May be null, if
 *  no dimensions are desired.
 * @param {Number} val The amount by which to decrement the counter (default: 1)
 * @param {Function(String)} callback A callback to be invoked after the
 *  message has been sent.  Most code can safely omit this.
 */
exports.dec = function dec(name, dimensions, val, callback) {
  if (! name) {
    throw new Error('No name specified');
  }
  if (dimensions && (typeof dimensions !== 'object')) {
    throw new Error('Dimensions must be an object');
  }
  if (val === null || val === undefined) {
    val = 1;
  }
  client.send(types.COUNTER, 'DEC', name, dimensions, val, callback);
};


/** 
 * Clears the specified counter (resets its value to 0) in the broker.
 *
 * @param {String} name The name of the counter.
 * @param {Object} dimensions The dimensions of the counter.  May be null, if
 *  no dimensions are desired.
 * @param {Function(String)} callback A callback to be invoked after the
 *  message has been sent.  Most code can safely omit this.
 */
exports.clear = function clear(name, dimensions, callback) {
  if (! name) {
    throw new Error('No name specified');
  }
  if (dimensions && (typeof dimensions !== 'object')) {
    throw new Error('Dimensions must be an object');
  }
  client.send(types.COUNTER, 'CLEAR', name, dimensions, null, callback);
};

==> metrics-broker-0.2.0.tgz: package/instruments/counter.js <==
/**
 * This file implements basic counter functionality for JavaScript programs
 * that use the metrics broker.
 *
 * Example code:
 *
 * require('metrics-broker/instruments').Counter;
 *
 * var name = 'actions';
 * var dimensions = { cust: 'custA', ... };
 * Counter.inc(name, dimensions, [val], [callback]);
 *
 * In most cases, val and callback may be omitted.
 *
 * See the README for more information on names and dimensions.
 */

var types = require('../broker').types;
var Client = require('../broker').Client;

/** 
 * Increments the specified counter in the broker.
 *
 * @param {String} name The name of the counter.
 * @param {Object} dimensions The dimensions of the counter.  May be null, if
 *  no dimensions are desired.
 * @param {Number} val The amount by which to increment the counter (default: 1)
 * @param {Function(String)} callback A callback to be invoked after the
 *  message has been sent.  Most code can safely omit this.
 */
exports.inc = function inc(name, dimensions, val, callback) {
  if (! name) {
    throw new Error('No name specified');
  }
  if (dimensions && (typeof dimensions !== 'object')) {
    throw new Error('Dimensions must be an object');
  }
  if (val === null || val === undefined) {
    val = 1;
  }
  Client.send(types.COUNTER, 'INC', name, dimensions, val, callback);
};


/** 
 * Decrements the specified counter in the broker.
 *
 * @param {String} name The name of the counter.
 * @param {Object} dimensions The dimensions of the counter.  May be null, if
 *  no dimensions are desired.
 * @param {Number} val The amount by which to decrement the counter (default: 1)
 * @param {Function(String)} callback A callback to be invoked after the
 *  message has been sent.  Most code can safely omit this.
 */
exports.dec = function dec(name, dimensions, val, callback) {
  if (! name) {
    throw new Error('No name specified');
  }
  if (dimensions && (typeof dimensions !== 'object')) {
    throw new Error('Dimensions must be an object');
  }
  if (val === null || val === undefined) {
    val = 1;
  }
  Client.send(types.COUNTER, 'DEC', name, dimensions, val, callback);
};


/** 
 * Clears the specified counter (resets its value to 0) in the broker.
 *
 * @param {String} name The name of the counter.
 * @param {Object} dimensions The dimensions of the counter.  May be null, if
 *  no dimensions are desired.
 * @param {Function(String)} callback A callback to be invoked after the
 *  message has been sent.  Most code can safely omit this.
 */
exports.clear = function clear(name, dimensions, callback) {
  if (! name) {
    throw new Error('No name specified');
  }
  if (dimensions && (typeof dimensions !== 'object')) {
    throw new Error('Dimensions must be an object');
  }
  Client.send(types.COUNTER, 'CLEAR', name, dimensions, null, callback);
};
